@@ -8,6 +8,7 @@ import json
 
 
 if __name__ == '__main__':
+    print('starting to populate')
     parser = argparse.ArgumentParser()
     parser.add_argument(
         "--schema", help="name of schema", type=str)
@@ -16,6 +17,12 @@ if __name__ == '__main__':
     parser.add_argument(
         "--kwargs", help="keyword arguments to pass to populate", type=str
     )
+    parser.add_argument(
+        "--user", help="username for sql database", type=str
+    )
+    parser.add_argument(
+        "--password", help="password for sql database", type=str
+    )
 
     args = parser.parse_args()
     # TODO connect as user?
@@ -33,7 +40,7 @@ if __name__ == '__main__':
         sys.path.append(filepath)
         from loris import config, conn
 
-    conn()
+    conn(user=args.user, password=args.password)
 
     table_class = getattr(
         config['schemata'][args.schema],
@@ -41,7 +48,10 @@ if __name__ == '__main__':
     )
 
     restriction = kwargs.pop('restriction')
-    print("restriction")
+    settings_name = kwargs.pop('settings_name')
+    print("settings_name:")
+    print(settings_name)
+    print("restriction:")
     print(restriction)
 
-    table_class.populate(restriction, **kwargs)
+    table_class.populate(settings_name, restriction, **kwargs)
